import os
import sys
from os.path import abspath, join
from gettext import gettext as _

cwd = abspath(os.path.dirname(sys.argv[0]))


class Theme:
    """Represents a GUI theme by defining UI elements (mostly icons)."""
    def __init__(self, theme_dir):
        """Set theme asset paths according to the given theme directory.
        
        :param str theme_dir: the directory containing a UI theme
        """
        self.path = theme_dir
        self.icon_about = join(self.path, 'about.png')
        self.icon_arrow_down = join(self.path, 'arrow_down.png')
        self.icon_arrow_up = join(self.path, 'arrow_up.png')
        self.icon_book_open = join(self.path, 'book_open.png')
        self.icon_bug_report = join(self.path, 'bug.png')
        self.icon_close = join(self.path, 'close.png')
        self.icon_donate = join(self.path, 'donate.png')
        self.icon_download = join(self.path, 'download.png')
        self.icon_downloaded = join(self.path, 'downloaded.png')
        self.icon_error = join(self.path, 'error.png')
        self.icon_find = join(self.path, 'find.png')
        self.icon_help = join(self.path, 'help.png')
        self.icon_home = join(self.path, 'home.png')
        self.icon_install = join(self.path, 'install.png')
        self.icon_layout = join(self.path, 'layout.png')
        self.icon_new = join(self.path, 'new.png')
        self.icon_open = join(self.path, 'open.png')
        self.icon_options = join(self.path, 'options.png')
        self.icon_package = join(self.path, 'package.png')
        self.icon_plugin = join(self.path, 'plugin.png')
        self.icon_plugin_add = join(self.path, 'plugin_add.png')
        self.icon_plugin_disable = join(self.path, 'plugin_disabled.png')
        self.icon_project_details = join(self.path, 'project_details.png')
        self.icon_quit = join(self.path, 'quit.png')
        self.icon_refresh = join(self.path, 'refresh.png')
        self.icon_sources = join(self.path, 'sources.png')
        self.icon_translate = join(self.path, 'translate.png')
        self.icon_update = join(self.path, 'update.png')
        self.icon_updates = join(self.path, 'get_updates.png')
        self.icon_uptodate = join(self.path, 'uptodate.png')

# Strings
name = 'Keryx'
subtitle = _('Bringing Updates Home.')
version = '0.92.5'

authors = 'Chris Oliver\nBuran Ayuthia\nmac9416\njacseen'
email = 'excid3@gmail.com'
artists = 'Chris Oliver'
docwriters = 'Chris Oliver'
translators = ''
copyright = '(C) 2008-2009 Chris Oliver'
description = name + _(' is a package manager for computers without internet.')
license = name + ' is free software; you can redistribute ' \
    'it and/or modify it under the terms of the GNU General Public ' \
    'License as published by the Free Software Foundation; either ' \
    'version 2 of the License, or (at your option) any later version.\n' \
    'Keryx is distributed in the hope that it will be useful, but ' \
    'WITHOUT ANY WARRANTY; without even the implied warranty of ' \
    'MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU ' \
    'General Public License for more details. You should have received ' \
    'a copy of the GNU General Public License along with Keryx; if ' \
    'not, write to the Free Software Foundation, Inc., 59 Temple ' \
    'Place, Suite 330, Boston, MA  02111-1307 USA'

# URLs
bug_url = 'https://bugs.launchpad.net/keryx'
donate_url = 'http://keryxproject.org/donate'
help_url = 'http://keryxproject.org/forum'
homepage_url = 'http://keryxproject.org'
tutorial_url = join(cwd, 'doc', 'sphinx', 'tutorial.html')
translate_url = 'https://translations.launchpad.net/keryx'

# Directories
locale_dir = abspath(join(cwd, 'locale'))
log_dir = abspath(join(cwd, 'logs'))
projects_dir = abspath(join(cwd, 'projects'))

# Files
log_path = join(log_dir, 'log')

# UI assets paths
pixmaps_dir = join(cwd, 'pixmaps')
themes_dir = join(pixmaps_dir, 'themes')
default_theme_dir = join(themes_dir, 'default')
theme = Theme(default_theme_dir)

# Logo
ico_path = join(pixmaps_dir, 'keryx.ico')
logo_path = join(pixmaps_dir, 'keryx.png')
