# -*- coding: utf-8 -*-
#
# Author: Chris Oliver (excid3@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

from . import config
import logging
import os

from logging.handlers import RotatingFileHandler

# Make sure the directory exists
if not os.path.exists(config.log_dir):
    os.mkdir(config.log_dir)

__logHandler = RotatingFileHandler(config.log_path, maxBytes=0, backupCount=2)
__logHandler.doRollover()
__logHandler.setFormatter(
    logging.Formatter('[%(asctime)s] %(levelname)-7s %(message)s',
                      datefmt='%y-%m-%d %H:%M:%S'))

logger = logging.getLogger(config.name.lower())
logger.setLevel(logging.INFO)
logger.addHandler(__logHandler)


def info(status):
    """Print status to log file and to console.
    
    :param str status: the status to be logged
    """
    logger.info(status)
    print(status)


def error(status):
    """Print error to log file and to console.
    
    :param str status: the status to be logged
    """
    logger.error(status)
    print(status)
