class Package:
    """Represents a package in the APT system, as described in the lists from
    some package repository.
    """
    def __init__(self,
                 name,
                 version='',
                 description='',
                 filename='',
                 size='',
                 depends='',
                 recommends='',
                 pre_depends='',
                 checksums=None,
                 status='',
                 installed_version=''):
        """Sets the initial values for this Package.
        
        :param str name: the name of this package
        :param str version: the version of this package
        :param str description: the description of this package
        :param str filename: the filename of this package
        :param str size: the size of this package
        :param list depends: a list of packages this one depends on
        :type depends: None or list
        :param recommends: a list of packages this one recommends
        :type recommends: None or list
        :param pre_depends: a list of pre-dependencies for this package
        :type pre_depends: None or list
        :param checksums: a dictionary of algorithm: checksum pairs
        :type checksums: None or dict
        """
        self.name = name
        self.version = version
        self.description = description
        self.filename = filename
        self.size = size
        self.depends = depends
        self.recommends = recommends
        self.pre_depends = pre_depends
        self.checksums = checksums
        self.status = status
        self.installed_version = installed_version
