# -*- coding: utf-8 -*-
#
# Author: Chris Oliver (excid3@gmail.com)
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA

import os

import time

from lib import debian
from . import config
from . import log

# Make sure the directory exists
if not os.path.exists(config.projects_dir):
    os.mkdir(config.projects_dir)

# The currently-opened project
current = None


class ProjectExistsException(Exception):
    pass


def create_project(project_name):
    """Create a project with the given name and plugin."""
    # Get the full path of the new project's directory
    project_dir = os.path.join(config.projects_dir, project_name)

    # Make sure a project by that name doesn't already exist
    if os.path.exists(project_dir):
        raise ProjectExistsException

    # Write the basic project information to the project directory
    os.mkdir(project_dir)

    # Write the remaining project information to the project file
    debian.create_project(project_name)

    log.info('Created project: ' + project_name)


class Project(object):
    """Stores project information and common tasks"""
    def __init__(self,
                 name='',
                 directory='',
                 plugin=None,
                 comp='',
                 os_name='',
                 ver='',
                 arch='',
                 kernel=''):
        self.name = name
        self.dir = directory
        self.plugin = plugin
        self.comp_name = comp
        self.os_name = os_name
        self.os_version = ver
        self.os_arch = arch
        self.kernel_name = kernel
        self.packages = {}

    def get_data(self):
        return [self.name,
                self.dir,
                self.os_name,
                self.os_version,
                self.os_arch,
                self.kernel_name]

    def set_data(self,
                 name='',
                 directory='',
                 plugin=None,
                 comp='',
                 os_name='',
                 ver='',
                 arch='',
                 kernel=''):
        self.name = name
        self.dir = directory
        self.plugin = plugin
        self.comp_name = comp
        self.os_name = os_name
        self.os_version = ver
        self.os_arch = arch
        self.kernel_name = kernel

    def open_project(self, name):
        """Opens a project"""
        self.name = name
        self.dir = os.path.join(config.projects_dir, name)

        self.comp_name = debian.get_comp_name()
        self.os_name = debian.get_os_name()
        self.os_version = debian.get_os_version()
        self.os_arch = debian.get_os_arch()
        self.kernel_name = debian.get_kernel_name()

    def get_dependencies(self, package):
        """Gets dependencies for package"""
        return debian.get_dependencies(os.path.join(self.dir, 'packages'),
                                       self.packages,
                                       package)

    def get_urls(self):
        return debian.load_remote_package_list(self.dir, self.os_arch)

    def load_local(self, jobID, abortEvent):
        self.packages = debian.load_local_package_list(self.dir, self.os_arch)

        return True

    def get_sources(self):
        return debian.get_sources(self.dir)
