from lib import join_url


class Source:
    """Represents a line from an APT sources file."""
    def __init__(self, line, arch):
        """Sets up the source's information based on the given deb line.
        
        :param str line: a line from an APT sources file
        :param str arch: either '32bit' or '64bit'
        """
        self.line = line
        self.arch = arch
        self.urls = self.__get_urls()
        self.filenames = self.__get_filenames()

    def __get_urls(self):
        """Get the URLs of index files associated with this source."""
        parts = self.line.split()
        repo_url = parts[1]
        dist = parts[2]
        for section in parts[3:]:
            url = join_url(repo_url, 'dists', dist, section)

            if self.arch == '32bit':
                url = join_url(url, 'binary-i386/Packages.gz')
            elif self.arch == '64bit':
                url = join_url(url, 'binary-amd64/Packages.gz')

            yield url

    def __get_filenames(self):
        """Get a list of filenames for index files in this repo. It's the path
        to the file on the server with slashes replaced by underscores and the
        .gz file extension removed.
        """
        for url in self.urls:
            # Simply remove the protocol designator and replace slashes with
            # underscores.
            path = url.split('//')[1]
            yield path.replace('/', '_')
