def version_compare(str1, str2):
    ver1 = Version(str1)
    ver2 = Version(str2)

    ver_type = ('epoch', 'upstream', 'debian')
    test_type = (0, 2, 1)

    parse1 = []
    parse2 = []

    version_list1 = (ver1.epoch(), ver1.upstream(), ver1.debian_version())
    version_list2 = (ver2.epoch(), ver2.upstream(), ver2.debian_version())

    for index in range(3):
        equal = __compare_info(version_list1[index], version_list2[index], ver_type[index])
        if equal != 0:
            break

    return equal


def __compare_info(string1, string2, ver_type):
    equal = 0
    if string1 and string2:  # Both strings contain a value
        parse1 = parse_version(string1)
        parse2 = parse_version(string2)

        max = len(parse1)
        if len(parse1) > len(parse2):
            max = len(parse2)
        # Go through the parsed list of the version number, broken down by
        # type
        for count in range(max):
            compare1 = parse1[count][1]
            type1 = parse1[count][0]
            compare2 = parse2[count][1]
            type2 = parse2[count][0]
            if type1 == 'alpha'   and type2 == 'alpha' or \
               type1 == 'num'     and type2 == 'num'       or \
               type1 == 'delimit' and type2 == 'delimit':
                if compare1 < compare2:
                    equal = 1
                    break
                elif compare1 > compare2:
                    equal = 2
                    break
            elif type1 == 'alpha'   and type2 == 'num'     or \
                 type1 == 'alpha'   and type2 == 'delimit' or \
                 type1 == 'alpha'   and type2 == 'tilde'   or \
                 type1 == 'num'     and type2 == 'tilde'   or \
                 type1 == 'delimit' and type2 == 'num'     or \
                 type1 == 'delimit' and type2 == 'tilde':
                equal = 2
                break
            elif type1 == 'num'     and type2 == 'alpha'   or \
                 type1 == 'num'     and type2 == 'delimit' or \
                 type1 == 'tilde'   and type2 == 'alpha'   or \
                 type1 == 'tilde'   and type2 == 'num'     or \
                 type1 == 'tilde'   and type2 == 'delimit' or \
                 type1 == 'delimit' and type2 == 'alpha':
                equal = 1
                break
            elif type1 == 'tilde'   and type2 == 'tilde':
                # The more tilde characters, the less its value
                if len(str(compare1)) > len(str(compare2)):
                    equal = 1
                    break
                elif len(str(compare1)) < len(str(compare2)):
                    equal = 2
                    break
        if equal == 0:
            if len(parse1) > max:
                compare1 = parse1[max][1]
                type1 = parse1[max][0]
#                    print compare1,
#                    print type1
                if type1 == 'num' or \
                   type1 == 'alpha' or \
                   type1 == 'delimit':
                    equal = 2
                elif type1 == 'tilde':
                    equal = 1
            elif len(parse2) > max:
                compare2 = parse2[max][1]
                type2 = parse2[max][0]
                if type2 == 'num' or \
                   type2 == 'alpha' or \
                   type2 == 'delimit':
                    equal = 1
                elif type1 == 'tilde':
                    equal = 2

    elif ver_type == 'epoch'  and string1 and not string2 or \
         ver_type == 'debian' and not string1 and string2:
        equal = 1
    elif ver_type == 'debian' and string1 and not string2 or \
         ver_type == 'epoch'  and not string1 and string2:
        equal = 2

    return equal


def parse_version(version):
    version_list = []

    # Tracks the current string type (num, alpha, delimit, tilde)
    build_type = ''
    string_val = ''

    for char in version:
        if __type_changed(build_type, char):
            # If the build type is not empty (there is a string ready to be
            # appended)
            if build_type:
                if string_val.isdigit():
                    # Convert string to integer
                    version_list.append([build_type, int(string_val)])
                    string_val = ''
                else:
                    version_list.append([build_type, string_val])
                    string_val = ''
            build_type = __get_type(char)
        string_val += char

    if build_type:
        if string_val.isdigit():
            version_list.append([build_type, int(string_val)])
        else:
            version_list.append([build_type, string_val])

    return version_list  # returns a list of [build_type, string_val]


def __type_changed(build_type, char):
    ret_val = False

    if (char.isdigit() and build_type != 'num') or \
       (char.isalpha() and build_type != 'alpha') or \
       (build_type == 'num' and not char.isdigit()) or \
       (build_type == 'alpha' and not char.isalpha()) or \
       (build_type == 'tilde' and char != '~') or \
       (build_type == 'delimit' and (char == '~' or char.isdigit() or char.isalpha())):
        ret_val = True

    return ret_val


def __get_type(char):
    ret_type = ''
    if char.isalpha():
        ret_type = 'alpha'
    elif char.isdigit():
        ret_type = 'num'
    elif char == '~':
        ret_type = 'tilde'
    else:
        ret_type = 'delimit'

    return ret_type


class Version:
    """This class represents the version of a package and provides certain tools
    to learn information about that version.
    """
    def __init__(self, ver_string):
        self.version = ver_string
        self.epoch_value = self.__get_epoch(self.version)
        upstream_deb = self.__get_upstrdeb(self.version)
        self.upstream_value = upstream_deb[0]
        self.debver_value = upstream_deb[1]

    def epoch(self):
        return self.epoch_value

    def upstream(self):
        return self.upstream_value

    def debian_version(self):
        return self.debver_value

    def __get_epoch(self, str1):
        ret_epoch = []
        epoch = str1.split(':')
        if len(epoch) > 1:
            ret_epoch = epoch[0]

        return ret_epoch

    def __get_upstrdeb(self, str1):
        ver_list = []
        version = str1.split('-')

        debver = ''
        upstream = ''

        if len(version) > 1:
            debver = version[len(version) - 1]
            for index in range(len(version) - 1):
                if index == 0:
                    upstream = version[index]
                else:
                    upstream += '-' + version[index]
        else:
            upstream = str1

        return [upstream, debver]
